#!/usr/local/bin/python
#
# Name        :  HadoopRackParser.py
# Purpose     :  Script used to extract rack locality information from the 
#                "INFO" lines output during a Map-Reduce run.  Extracts
#                numbers of tasks in the Job Counters.  Assumes contents:
#                  Rack-local map tasks=<#>
#                  Data-local map tasks=<#>
#                  Launched map tasks=<#>
# Created     :  March 4, 2009
# Last Updated:  September 28, 2009
#
# Usage       :  cat <file-list> | python HadoopRackParser.py > <outfilename>
#
# Copyright (c) 2009, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# LLNL-CODE-416230
# All rights reserved.
#
# This file is part of the Data-Intensive Benchmark Suite.
# Please read the COPYRIGHT, LICENSE, and NOTICE files that came with this
# distribution.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License (as published by
# the Free Software Foundation) version 2.1 dated February 1999.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
# conditions of the GNU Lesser General Public License for more details.
#
# You should have recieved a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#

import string
#

import string

#
#####################################################

FALSE = 0
TRUE  = 1
SEP = ';'
TITLES = [
  'Data-Local Map Tasks',
  'Rack-Local Map Tasks',
  'Launched Map Tasks',
]

def numToStr(val):
  return '%s' % val

def extractNum(line):
  num = -1
  ind = line.find('=')
  if (ind > 0):
    num = line[ind+1:len(line)-1]
  else:
    num = 0
  return num


class ClassifierTiming:

  def __init__(self):
    self.init = FALSE
    self.numDataLocalMaps = 0
    self.numRackLocalMaps = 0
    self.numLaunchedMaps = 0
    print SEP.join(TITLES)

  def writeData(self):
    if self.init:
      vals = [ self.numDataLocalMaps, 
               self.numRackLocalMaps, 
               self.numLaunchedMaps ]
      print SEP.join(vals)
      self.numDataLocalMaps = 0
      self.numRackLocalMaps = 0
      self.numLaunchedMaps = 0

  def setDataLocalMaps(self, line):
    self.numDataLocalMaps = extractNum(line)
    if (self.numDataLocalMaps > 0):
      self.init = TRUE

  def setRackLocalMaps(self, line):
    self.numRackLocalMaps = extractNum(line)
    if (self.numRackLocalMaps > 0):
      self.init = TRUE

  def setLaunchedMaps(self, line):
    self.numLaunchedMaps = extractNum(line)
    if (self.numLaunchedMaps > 0):
      self.init = TRUE


#
#####################################################
#                     MAIN
#####################################################
#
if __name__ == '__main__':
  import sys
  timing = ClassifierTiming()
  try:
    for line in sys.stdin:
      if (line != None):
        if (line.find('Rack-local map') >= 0):
          timing.writeData()
          timing.setRackLocalMaps(line)
        elif (line.find('Launched map tasks') >= 0):
          timing.setLaunchedMaps(line)
        elif (line.find('Data-local map tasks') >= 0):
          timing.setDataLocalMaps(line)
    timing.writeData()
  except:
    (type, value, trace) = sys.exc_info()
    import traceback
    traceback.print_exception(type, value, trace)
0
