#!/bin/csh
#
# Name        :  setupTFIDF.csh
# Purpose     :  Set environment variables for using the Hadoop TF-IDF 
#                classifier.
# Created     :  May 7, 2009
# Last Updated:  September 28, 2009
#
# Note        :  The following should be tailored to your environment:
#                   JAVA_HOME, 
#                   HADOOP_VERSION, HADOOP_HOME, HADOOP_JARS, and 
#                   HTFIDF_HOME
#
# Copyright (c) 2009, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# LLNL-CODE-416230
# All rights reserved.
#
# This file is part of the Data-Intensive Benchmark Suite.
# Please read the COPYRIGHT, LICENSE, and NOTICE files that came with this
# distribution.
#

#
# Installation-specific environment variables
# ...Root of the JAVA installation (used to build HADOOP)
setenv JAVA_HOME /usr/apps/java/jdk1.6.0_11

# ...Root of the Hadoop installation
setenv HADOOP_VERSION 0.19.0
setenv HADOOP_HOME /usr/apps/hadoop-${HADOOP_VERSION}
setenv HADOOP_JARS ${HADOOP_HOME}

# ...Root of the Hadoop TF-IDF 'distribution'
setenv HTFIDF_HOME ${HOME}/classifiers/TFIDF/tfidf-hadoop

#
# Environment variables dependent on tailored variables above
# ...Hadoop
setenv HADOOP_BIN       ${HADOOP_HOME}/bin
setenv HADOOP_LIB       ${HADOOP_HOME}/lib

setenv HADOOP_CORE_JAR  ${HADOOP_JARS}/hadoop-${HADOOP_VERSION}-core.jar
setenv HADOOP_TOOLS_JAR ${HADOOP_JARS}/hadoop-${HADOOP_VERSION}-tools.jar

# ...Hadoop TF-IDF
setenv HTFIDF_BIN       ${HTFIDF_HOME}/bin
setenv HTFIDF_CLASSES   ${HTFIDF_HOME}/classes
setenv HTFIDF_LIB       ${HTFIDF_HOME}/lib
setenv HTFIDF_SRC       ${HTFIDF_HOME}/src

setenv HTFIDF_JAR       ${HTFIDF_LIB}/htfidfClassifierV1.jar

# ...Local file system data and results directories (for experiment scripts)
setenv HTFIDF_DATA      ${HTFIDF_HOME}/data		# Base data directory
setenv HTFIDF_RES       ${HTFIDF_HOME}/results		# Results root directory

#
# Default Hadoop DFS directories (for experiment scripts)
setenv HTFIDF_HDATA     AttackClassifier/data		# Data root directory
setenv HTFIDF_HRES      AttackClassifier/results	# Results root directory

#
# Default Hadoop TF-IDF model file
setenv HTFIDF_HMODEL ${HTFIDF_HDATA}/defaultModel/ecmlTrainTestNoDupModel.data

#
# Set up PATH
echo $PATH | grep -q ${JAVA_HOME}/bin
if $status then
   setenv PATH ${JAVA_HOME}/bin:${PATH}
endif

echo $PATH | grep -q ${HADOOP_BIN}
if $status then
   setenv PATH ${HADOOP_BIN}:${PATH}
endif

echo $PATH | grep -q ${HTFIDF_BIN}
if $status then
   setenv PATH ${HTFIDF_BIN}:${PATH}
endif

#
# Set up LD_LIBRARY_PATH
#if ( $?LD_LIBRARY_PATH ) then
#   echo $LD_LIBRARY_PATH | grep -q ${HADOOP_LIB}
#   if $status then
#      setenv LD_LIBRARY_PATH ${HADOOP_LIB}:${LD_LIBRARY_PATH}
#   endif
#
#   echo $LD_LIBRARY_PATH | grep -q ${HTFIDF_LIB}
#   if $status then
#      setenv LD_LIBRARY_PATH ${HTFIDF_LIB}:${LD_LIBRARY_PATH}
#   endif
#else
#   setenv LD_LIBRARY_PATH ${HTFIDF_LIB}:${HADOOP_LIB}
#endif

#
# Set up CLASSPATH
if ( $?CLASSPATH ) then
   echo $CLASSPATH | grep -q ${HADOOP_CORE_JAR}
   if $status then
      setenv CLASSPATH ${HADOOP_CORE_JAR}:${CLASSPATH}
   endif

   echo $CLASSPATH | grep -q ${HADOOP_TOOLS_JAR}
   if $status then
      setenv CLASSPATH ${HADOOP_TOOLS_JAR}:${CLASSPATH}
   endif

   echo $CLASSPATH | grep -q ${HTFIDF_JAR}
   if $status then
      setenv CLASSPATH ${HTFIDF_JAR}:${CLASSPATH}
   endif
else
  setenv CLASSPATH ${HTFIDF_JAR}:${HADOOP_TOOLS_JAR}:${HADOOP_CORE_JAR}
endif

#
# Finally flag that we're done (for experiment scripts)
setenv HTFIDF_SETUP_DONE TRUE
