#!/bin/sh
#
# Name        :  setupTFIDF.sh
# Purpose     :  Set environment variables for using the Hadoop TF-IDF 
#                classifier.
# Created     :  May 7, 2009
# Last Updated:  September 28, 2009
#
# Note        :  The following should be tailored to your environment:
#                   JAVA_HOME, 
#                   HADOOP_VERSION, HADOOP_HOME, HADOOP_JARS, and 
#                   HTFIDF_HOME
#
# Copyright (c) 2009, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
# LLNL-CODE-416230
# All rights reserved.
#
# This file is part of the Data-Intensive Benchmark Suite.
# Please read the COPYRIGHT, LICENSE, and NOTICE files that came with this
# distribution.
#

#
# Installation-specific environment variables
# ...Root of the JAVA installation (used to build HADOOP)
export JAVA_HOME="/usr/apps/java/jdk1.6.0_11"

# ...Root of the Hadoop installation
export HADOOP_VERSION="0.19.0"
export HADOOP_HOME="/usr/apps/hadoop-${HADOOP_VERSION}"
export HADOOP_JARS="${HADOOP_HOME}"

# ...Root of the Hadoop TF-IDF 'distribution'
export HTFIDF_HOME="${HOME}/classifiers/TFIDF/tfidf-hadoop"

#
# Environment variables dependent on tailored variables above
# ...Hadoop
export HADOOP_BIN="${HADOOP_HOME}/bin"
export HADOOP_LIB="${HADOOP_HOME}/lib"
export HADOOP_CORE_JAR="${HADOOP_JARS}/hadoop-${HADOOP_VERSION}-core.jar"
export HADOOP_TOOLS_JAR="${HADOOP_JARS}/hadoop-${HADOOP_VERSION}-tools.jar"

# ...Hadoop TF-IDF
export HTFIDF_BIN="${HTFIDF_HOME}/bin"
export HTFIDF_CLASSES="${HTFIDF_HOME}/classes"
export HTFIDF_LIB="${HTFIDF_HOME}/lib"
export HTFIDF_SRC="${HTFIDF_HOME}/src"

export HTFIDF_JAR="${HTFIDF_LIB}/htfidfClassifierV1.jar"

# ...Local file system data and results directories (for experiment scripts)
export HTFIDF_DATA="${HTFIDF_HOME}/data"	# Base data directory
export HTFIDF_RES="${HTFIDF_HOME}/results"	# Results root directory

#
# Default Hadoop DFS directories (for experiment scripts)
export HTFIDF_HDATA="AttackClassifier/data"	# Data root directory
export HTFIDF_HRES="AttackClassifier/results"	# Results root directory

#
# Default Hadoop TF-IDF model file
export HTFIDF_HMODEL="${HTFIDF_HDATA}/defaultModel/ecmlTrainTestNoDupModel.data"

#
# Set up PATH
echo $PATH | grep -q $JAVA_HOME/bin
if [ $? -ne 0 ] ; then
   PATH=${JAVA_HOME}/bin:${PATH}
fi

echo $PATH | grep -q $HADOOP_BIN
if [ $? -ne 0 ] ; then
   PATH=${HADOOP_BIN}:${PATH}
fi

echo $PATH | grep -q $HTFIDF_BIN
if [ $? -ne 0 ] ; then
   PATH=${HTFIDF_BIN}:${PATH}
fi

export PATH

#
# Set up LD_LIBRARY_PATH
#if [ $LD_LIBRARY_PATH ] ; then
#   echo $LD_LIBRARY_PATH | grep -q $HADOOP_LIB
#   if [ $? -ne 0 ] ; then
#      LD_LIBRARY_PATH=${HADOOP_LIB}:${LD_LIBRARY_PATH}
#   fi
#
#   echo $LD_LIBRARY_PATH | grep -q $HTFIDF_LIB
#   if [ $? -ne 0 ] ; then
#      LD_LIBRARY_PATH=${HTFIDF_LIB}:${LD_LIBRARY_PATH}
#   fi
#else
#   LD_LIBRARY_PATH=${HTFIDF_LIB}:${HADOOP_LIB}
#fi
#
#export LD_LIBRARY_PATH

#
# Set up CLASSPATH
if [ $CLASSPATH ] ; then
   echo $CLASSPATH | grep -q ${HADOOP_CORE_JAR}
   if [ $? -ne 0 ] ; then
      CLASSPATH=${HADOOP_CORE_JAR}:${CLASSPATH}
   fi

   echo $CLASSPATH | grep -q ${HADOOP_TOOLS_JAR}
   if [ $? -ne 0 ] ; then
      CLASSPATH=${HADOOP_TOOLS_JAR}:${CLASSPATH}
   fi

   echo $CLASSPATH | grep -q ${HTFIDF_JAR}
   if [ $? -ne 0 ] ; then
      CLASSPATH=${HTFIDF_JAR}:${CLASSPATH}
   fi
else
  CLASSPATH=${HTFIDF_JAR}:${HADOOP_TOOLS_JAR}:${HADOOP_CORE_JAR}
fi

export CLASSPATH

#
# Finally flag that we're done (for experiment scripts)
export HTFIDF_SETUP_DONE="TRUE"
