/**
 * Name   :  ClassificationDriver.java
 * Purpose:  This is a Hadoop Map/Reduce program driver for TF-IDF
 *           classification.
 * Author :  T. Dahlgren
 * Created:  January 5, 2009
 *
 * Usage  :     
 * >  ${HADOOP_BIN}/bin/hadoop jar ${HADOOP_JAR} ClassificationDriver \
 * 		 classifier input-dir args
 *    #
 *    # where classifier is the desired classifier
 *    #       input-dir is location in HDFS of the request file 
 *    #       args is the remaining arguments associated with the program
 *
 * Acknowledgments:  
 *   This class is based on Hadoop's ExampleDriver.
 *     
 * Copyright (c) 2009, Lawrence Livermore National Security, LLC.
 * Produced at the Lawrence Livermore National Laboratory.
 * LLNL-CODE-416230
 * All rights reserved.
 *
 * This file is part of the Data-Intensive Benchmark Suite.
 * Please read the COPYRIGHT, LICENSE, and NOTICE files that came with this
 * distribution.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License (as published by
 * the Free Software Foundation) version 2.1 dated February 1999.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
 * conditions of the GNU Lesser General Public License for more details.
 *
 * You should have recieved a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package gov.llnl.hadoop.classifier;

import gov.llnl.hadoop.classifier.httpRequest.TFIDFAttackClassifierV1;
import gov.llnl.hadoop.classifier.httpRequest.TFIDFAttackModelBuilderV1;

import java.lang.String;
import java.lang.Throwable;

import org.apache.hadoop.util.ProgramDriver;

/**
 * A classification-related program driver.
 */
public class ClassificationDriver {
    public static void main(String argv[]) {
        int res = -1;
        ProgramDriver pDriver = new ProgramDriver();
        try {
            pDriver.addClass(TFIDFAttackModelBuilderV1.g_lt_myName,
                    TFIDFAttackModelBuilderV1.class, 
                    "TF-IDF model builder for http attack classification "
                    + "(version 1).");
            pDriver.addClass(TFIDFAttackClassifierV1.g_lt_myName,
                    TFIDFAttackClassifierV1.class,
                    "A TF-IDF Classifier for HTTP Attacks (version 1).");
            pDriver.driver(argv);

            // Success
            res = 0;
        } catch (Throwable e) {
            e.printStackTrace();
        }

        System.exit(res);
    } // main()
} // ClassificationDriver
