<?xml version="1.0" encoding="UTF-8"?>
<!--
  Name        :  UnlabeledAttackData.xsl
  Author      :  T. Dahlgren
  Created     :  January 13, 2009
  Last Updated:  June 3, 2009
  Input       :  An XML file containing multiple entries of the form:
                    <sample id="anId">
                       <class>
                          <type>aType</type>
                       </class>
                       <request>
                          <method>aMethod</method>
                          <protocol>aProtocol</protocol>
                          <uri>aURI</uri>
                          <query>aQuery</query>
                          <headers>aHeader</headers>
                          <body>aBody</body>
                       </request>
                    </sample>
                 Other than <sample>, all other tags are optional.  Also
                 parent elements of <sample> and any other child elements
                 of <class> or <request> are ignored.
  Output      :  The basic layout is:
		    <sample.id>\t<class.type>\t<request>
                 though not all elements are expected to be present.  
                 Specifically, each output line could take one of the
                 following three forms:
                    (1)  <sample.id>\t<class.type>\t<request>
                    (2)  <sample.id>\t<request>
                    (3)  <sample.id>\t<class.type>
                 where (1) is the output form for the training dataset;
                       (2) is the output form for the test dataset; and
                       (3) is the output form for the test label set.
  
  Copyright (c) 2009, Lawrence Livermore National Security, LLC.
  Produced at the Lawrence Livermore National Laboratory.
  LLNL-CODE-2009-xyz
  All rights reserved.

  This file is part of the Data-Intensive Benchmark Suite.
  Please read the COPYRIGHT file for Our Notice and the LICENSE file for
  the GNU Lesser General Public License.

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License (as published by
  the Free Software Foundation) version 2.1 dated February 1999.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the IMPLIED WARRANTY OF
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the terms and
  conditions of the GNU Lesser General Public License for more details.

  You should have recieved a copy of the GNU Lesser General Public License
  along with this program; if not, write to the Free Software Foundation,
  Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="text" indent="no"/>
<xsl:strip-space elements="*" />
			
<xsl:template match="/">
	<xsl:apply-templates/>
</xsl:template>
			
<xsl:template match="sample">
	<xsl:value-of select="@id"/><xsl:text>	</xsl:text>
	<xsl:if test="class">
		<xsl:apply-templates select="class"/>
	</xsl:if>
	<xsl:if test="request">
		<xsl:apply-templates select="request"/>
	</xsl:if>
	<xsl:text>
</xsl:text>
</xsl:template>
 
<xsl:template match="class">
	<xsl:value-of select="type"/><xsl:text>	</xsl:text>
</xsl:template>

<xsl:template match="request">
	<xsl:value-of select="method"/><xsl:text> </xsl:text>
	<xsl:value-of select="protocol"/><xsl:text> </xsl:text>
	<xsl:value-of select="uri"/><xsl:text> </xsl:text>
	<xsl:value-of select="query"/><xsl:text> </xsl:text>
	<xsl:if test="headers">
		<xsl:call-template name="stripCRLF">
			<xsl:with-param name="myStr" select="headers"/>
		</xsl:call-template>
		<xsl:text> </xsl:text>
	</xsl:if>
	<xsl:if test="body">
		<xsl:value-of select="body"/>
	</xsl:if>
</xsl:template>

<xsl:template name="stripCRLF">
	<xsl:param name="myStr"/>
	<xsl:variable name="destStr">
		<xsl:choose>
		<xsl:when test="contains($myStr, '&#10;')">
                	<xsl:call-template name="stripCRLF">
				<xsl:with-param name="myStr" select="substring-before($myStr, '&#10;')"/>
                	</xsl:call-template>
			<xsl:text> </xsl:text>
                	<xsl:call-template name="stripCRLF">
				<xsl:with-param name="myStr" select="substring-after($myStr, '&#10;')"/>
                	</xsl:call-template>
		</xsl:when>
		<xsl:when test="contains($myStr, '&#13;')">
                	<xsl:call-template name="stripCRLF">
				<xsl:with-param name="myStr" select="substring-before($myStr, '&#13;')"/>
                	</xsl:call-template>
			<xsl:text> </xsl:text>
                	<xsl:call-template name="stripCRLF">
				<xsl:with-param name="myStr" select="substring-after($myStr, '&#13;')"/>
                	</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
       			<xsl:value-of select="$myStr"/>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:value-of select="$destStr"/>
</xsl:template>

<!-- Try ONLY if XSLT 2.0 supported...
<xsl:template match="headers">
	<xsl:text> headers: </xsl:text>
	xsl:analyze-string select="." regex="\s*">
	<xsl:non-matching-substring>
		<xsl:value-of select="."/>
	</xsl:non-matching-substring>
	<xsl:non-matching-substring>
		<xsl:value-of select=" "/>
	</xsl:non-matching-substring>
	</xsl:analyze-string>
	<xsl:value-of select="headers"/>
</xsl:template>
-->

</xsl:stylesheet>
