/**
 * Name   :  XSLTransformer.java
 * Purpose:  Simple XSL transformation program.
 *
 * Source:  
 *   Eric M. Burke, "Top Ten Java and XSLT Tips", 08/29/2001
 *   http://www.oreillynet.com/pub/a/oreilly/java/news/javaxslt_0801.html
 *     
 * Rationale:   
 *   Use of XSL intended to facilitate potential integration into Hadoop
 *   jobs since, at present, XSL is best documented means of parsing XML 
 *   in Hadoop.
 */


import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamSource;
import javax.xml.transform.stream.StreamResult;
import java.io.*;

public class XSLTransformer {

    /**
     * Performs an XSLT transformation, sending the results
     * to System.out.
     */
    public static void main(String[] args) throws Exception {
        if (args.length != 2) {
            System.err.println(
                "Usage: java XSLTransformer [xmlfile] [xsltfile]");
            System.exit(1);
        }

        File xmlFile = new File(args[0]);
        File xsltFile = new File(args[1]);

        /*
         * JAXP reads data using the Source interface
         */
        Source xmlSource = new StreamSource(xmlFile);
        Source xsltSource = new StreamSource(xsltFile);

        /*
         * The factory pattern supports different XSLT processors
         */
        TransformerFactory transFact =
                TransformerFactory.newInstance();
        Transformer trans = transFact.newTransformer(xsltSource);

        trans.transform(xmlSource, new StreamResult(System.out));
    }
} // XSLTransformer
